@@ -4,7 +4,7 @@ import imp
 def TTSnorm(text, punc = False, unknown = True, lower = True, rule = False ):
     A=imp.find_module('vinorm')[1]
 
-    print(A)
+    #print(A)
     I=A+"/input.txt"
     with open(I,"w+") as fw:
         fw.write(text)
@@ -13,15 +13,16 @@ def TTSnorm(text, punc = False, unknown = True, lower = True, rule = False ):
     myenv['LD_LIBRARY_PATH'] = A+'/lib'
 
     E=A+"/main"
-    if punc:
-        E=E+" -punc"
-    if unknown:
-        E=E+" -unknown"
-    if lower:
-        E=E+" -lower"
-    if rule:
-        E=E+" -rule"
-    subprocess.check_call([E], env=myenv, cwd=A)
+    #print(E)
+    # if punc:
+    #     E=E+" -punc"
+    # if unknown:
+    #     E=E+" -unknown"
+    # if lower:
+    #     E=E+" -lower"
+    # if rule:
+    #     E=E+" -rule"
+    subprocess.check_call([E], "-punc", env=myenv, cwd=A)
     
     O=A+"/output.txt"
     with open(O,"r") as fr:
@@ -31,7 +32,7 @@ def TTSnorm(text, punc = False, unknown = True, lower = True, rule = False ):
     for s in S:
         if s=="":
             continue
-        TEXT+=B+". "
+        TEXT+=s+". "
 
 
     return TEXT
\ No newline at end of file
